.. _async_client:

.. module:: akismet
  :noindex:


The asynchronous Akismet client
===============================


.. autoclass:: AsyncClient

   .. automethod:: validated_client
   .. automethod:: comment_check
   .. automethod:: key_sites
   .. automethod:: submit_ham
   .. automethod:: submit_spam
   .. automethod:: usage_limit
   .. automethod:: verify_key
